@@ -15,7 +15,7 @@ our @EXPORT_OK = (
 );
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v6.24.0";
+our $VERSION = "v6.25.0";
 
 1;
 __END__
@@ -61,7 +61,7 @@ The documentation in this POD applies to all three adapter modules as well.
 This module is an implementation of L<Reactive Extensions|http://reactivex.io/> in Perl. It replicates the
 behavior of L<rxjs 6|https://www.npmjs.com/package/rxjs> which is the JavaScript implementation of ReactiveX.
 
-Currently 94 of the 100+ operators in rxjs are implemented in this module.
+Currently 99 of the 100+ operators in rxjs are implemented in this module.
 
 =head1 EXPORTABLE FUNCTIONS
 
@@ -592,6 +592,33 @@ Do this instead, to achieve the expected effect:
 
     rx_timer(2)->pipe( op_ignore_elements() )
 
+=item op_delay_when
+
+L<https://rxjs.dev/api/operators/delayWhen>
+
+    # (pause 3 seconds) 3, (pause 1 second) 4, (pause one second) 5, complete
+    rx_of(3, 4, 5)->pipe(
+        op_delay_when(sub ($val, $idx) { rx_timer($val) }), # can also use $_ here
+    )->subscribe($observer);
+
+=item op_distinct
+
+L<https://rxjs.dev/api/operators/distinct>
+
+    # 1, 2, 3, 4, complete
+    rx_of(1, 1, 2, 2, 2, 1, 2, 3, 4, 3, 2, 1)->pipe(
+        op_distinct(),
+    )->subscribe($observer);
+
+    # { age => 4, name => 'Foo' }, { age => 7, name => 'Bar' }, complete
+    rx_of(
+        { age => 4, name => 'Foo'},
+        { age => 7, name => 'Bar'},
+        { age => 5, name => 'Foo'},
+    )->pipe(
+        op_distinct(sub ($val) { $val->{name} }), # can also use $_ here
+    )->subscribe($observer);
+
 =item op_distinct_until_changed
 
 L<https://rxjs.dev/api/operators/distinctUntilChanged>
@@ -1063,7 +1090,7 @@ L<https://rxjs.dev/api/operators/scan>
     # 0, 1, 3, 6, 10, ...
     rx_interval(1)->pipe(
         op_scan(sub {
-            my ($acc, $item) = @_;
+            my ($acc, $item, $idx) = @_;
             return $acc + $item;
         }, 0),
     )->subscribe($observer);
@@ -1109,6 +1136,15 @@ L<https://rxjs.dev/api/operators/skip>
         op_skip(3),
     )->subscribe($observer);
 
+=item op_skip_last
+
+L<https://rxjs.dev/api/operators/skipLast>
+
+    # (pause 3 seconds) 0, 1, 2, 3, 4, 5, 6, 7, complete
+    rx_interval(1)->pipe(
+        op_skip_last(2),
+    )->subscribe($observer);
+
 =item op_skip_until
 
 L<https://rxjs.dev/api/operators/skipUntil>
@@ -1251,6 +1287,26 @@ L<https://rxjs.dev/api/operators/throwIfEmpty>
         op_throw_if_empty(sub { "hello" }),
     )->subscribe($observer);
 
+=item op_time_interval
+
+L<https://rxjs.dev/api/operators/timeInterval>
+
+    # { value => 0, interval => 0.7 }, { vale => 1, interval => 0.7 }, complete
+    rx_interval(0.7)->pipe(
+        op_take(2),
+        op_time_interval(),
+    )->subscribe($observer);
+
+=item op_timestamp
+
+L<https://rxjs.dev/api/operators/timestamp>
+
+    # { value => 0, timestamp => 1675976745.17414 }, { value => 1, timestamp => 1675976746.17414 }, complete
+    rx_interval(1)->pipe(
+        op_take(2),
+        op_timestamp(),
+    )->subscribe($observer);
+
 =item op_to_array
 
 L<https://rxjs.dev/api/operators/toArray>
