@@ -12,22 +12,23 @@ use RxPerl::Subscription;
 
 use Carp 'croak';
 use Scalar::Util 'reftype', 'refaddr', 'blessed', 'weaken';
+use Time::HiRes ();
 
 use Exporter 'import';
 our @EXPORT_OK = qw/
     op_audit op_audit_time op_buffer op_buffer_count op_buffer_time op_catch_error op_combine_latest_with op_concat_all
-    op_concat_map op_concat_with op_count op_debounce op_debounce_time op_default_if_empty op_delay
-    op_distinct_until_changed op_distinct_until_key_changed op_element_at op_end_with op_every op_exhaust_all
-    op_exhaust_map op_filter op_finalize op_find op_find_index op_first op_group_by op_ignore_elements op_is_empty
-    op_last op_map op_map_to op_max op_merge_all op_merge_map op_merge_with op_min op_multicast
+    op_concat_map op_concat_with op_count op_debounce op_debounce_time op_default_if_empty op_delay op_delay_when
+    op_distinct op_distinct_until_changed op_distinct_until_key_changed op_element_at op_end_with op_every
+    op_exhaust_all op_exhaust_map op_filter op_finalize op_find op_find_index op_first op_group_by op_ignore_elements
+    op_is_empty op_last op_map op_map_to op_max op_merge_all op_merge_map op_merge_with op_min op_multicast
     op_on_error_resume_next_with op_pairwise op_pluck op_race_with op_reduce op_ref_count op_repeat op_retry op_sample
-    op_sample_time op_scan op_share op_single op_skip op_skip_until op_skip_while op_start_with op_switch_all
-    op_switch_map op_take op_take_last op_take_until op_take_while op_tap op_throttle op_throttle_time
-    op_throw_if_empty op_to_array op_with_latest_from op_zip_with
+    op_sample_time op_scan op_share op_single op_skip op_skip_last op_skip_until op_skip_while op_start_with
+    op_switch_all op_switch_map op_take op_take_last op_take_until op_take_while op_tap op_throttle op_throttle_time
+    op_throw_if_empty op_time_interval op_timestamp op_to_array op_with_latest_from op_zip_with
 /;
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v6.24.0";
+our $VERSION = "v6.25.0";
 
 sub op_audit {
     my ($duration_selector) = @_;
@@ -503,6 +504,113 @@ sub op_delay {
     };
 }
 
+sub op_delay_when {
+    my ($delay_duration_selector) = @_;
+
+    return sub {
+        my ($source) = @_;
+
+        return rx_observable->new(sub {
+            my ($subscriber) = @_;
+
+            my $idx = 0;
+            my %mini_subscriptions;
+            my $main_finished;
+
+            my $make_mini_subscriber = sub {
+                my ($v) = @_;
+
+                my $mini_subscription = RxPerl::Subscription->new;
+                $mini_subscriptions{$mini_subscription} = $mini_subscription;
+
+                return {
+                    new_subscription => $mini_subscription,
+                    next             => sub {
+                        $subscriber->{next}->($v) if defined $subscriber->{next};
+                    },
+                    error            => sub {
+                        $subscriber->{error}->(@_) if defined $subscriber->{error};
+                    },
+                    complete         => sub {
+                        delete $mini_subscriptions{$mini_subscription};
+                        if ($main_finished and ! %mini_subscriptions) {
+                            $subscriber->{complete}->() if defined $subscriber->{complete};
+                        }
+                    },
+                };
+            };
+
+            my $own_subscription = RxPerl::Subscription->new;
+            my $own_subscriber = {
+                new_subscription => $own_subscription,
+                next             => sub {
+                    my ($v) = @_;
+
+                    local $_ = $v;
+                    my $mini_obs = $delay_duration_selector->($v, $idx++);
+                    $mini_obs->subscribe($make_mini_subscriber->($v));
+                },
+                error            => sub {
+                    $subscriber->{error}->(@_) if defined $subscriber->{error};
+                },
+                complete         => sub {
+                    $main_finished = 1;
+                    if (!%mini_subscriptions) {
+                        $subscriber->{complete}->() if defined $subscriber->{complete};
+                    }
+                },
+            };
+
+            $subscriber->subscription->add($own_subscription, \%mini_subscriptions);
+
+            $source->subscribe($own_subscriber);
+
+            return;
+        });
+    };
+}
+
+sub op_distinct {
+    my ($key_selector) = @_;
+
+    return sub {
+        my ($source) = @_;
+
+        return rx_observable->new(sub {
+            my ($subscriber) = @_;
+
+            my %keys_passed;
+            $subscriber->subscription->add(sub { %keys_passed = () });
+
+            my $own_subscriber = {
+                %$subscriber,
+                next => sub {
+                    my ($v) = @_;
+
+                    my $k;
+                    if ($key_selector) {
+                        my $ok = eval { local $_ = $v; $k = $key_selector->($v); 1 };
+                        if (! $ok) {
+                            $subscriber->{error}->($@) if defined $subscriber->{error};
+                            return;
+                        }
+                    } else {
+                        $k = $v;
+                    }
+                    if (! exists $keys_passed{$k}) {
+                        $keys_passed{$k} = 1;
+                        $subscriber->{next}->($v) if defined $subscriber->{next};
+                    }
+                },
+            };
+
+            $source->subscribe($own_subscriber);
+
+            return;
+        });
+    };
+}
+
 sub op_distinct_until_changed {
     my ($comparison_function) = @_;
 
@@ -1689,6 +1797,36 @@ sub op_skip {
     };
 }
 
+sub op_skip_last {
+    my ($skip_count) = @_;
+
+    return sub {
+        my ($source) = @_;
+
+        return rx_observable->new(sub {
+            my ($subscriber) = @_;
+
+            my @skipped;
+            $subscriber->subscription->add(sub { undef @skipped });
+
+            my $own_subscriber = { %$subscriber };
+            $own_subscriber->{next} &&= sub {
+                my ($v) = @_;
+
+                push @skipped, $v;
+                if (@skipped > $skip_count) {
+                    my $new_v = shift @skipped;
+                    $subscriber->{next}->($new_v) if defined $subscriber->{next};
+                }
+            };
+
+            $source->subscribe($own_subscriber);
+
+            return;
+        });
+    };
+}
+
 sub op_skip_until {
     my ($notifier) = @_;
 
@@ -2096,6 +2234,32 @@ sub op_throw_if_empty {
     };
 }
 
+sub op_time_interval {
+    return sub {
+        my ($source) = @_;
+
+        my $t0 = Time::HiRes::time();
+
+        return $source->pipe(
+            op_map(sub {
+                my $now = Time::HiRes::time();
+                my $interval = $now - $t0;
+                $t0 = $now;
+                return { value => $_, interval => $interval };
+            }),
+        );
+    };
+}
+
+sub op_timestamp {
+    return op_map(sub {
+        return {
+            value     => $_,
+            timestamp => Time::HiRes::time(),
+        };
+    });
+}
+
 sub op_to_array {
     return sub {
         my ($source) = @_;
